==> hooks-1.0.4.tgz: package/lib/useFileDrop.js <==
import { debounce } from "@lincode/utils";
import { useEffect, useState } from "react";
export default (cb) => {
    const [dropEl, setDropEl] = useState();
    const [dragOver, setDragOver] = useState(false);
    useEffect(() => {
        if (!dropEl)
            return;
        const setDragOverDebounced = debounce((value) => setDragOver(value), 100, "trailing");
        let valueOld = false;
        const setDragOverTrack = (value) => {
            if (valueOld === value)
                return;
            valueOld = value;
            setDragOverDebounced(value);
        };
        const dragOverCb = (e) => {
            e.preventDefault();
            setDragOverTrack(true);
        };
        dropEl.addEventListener("dragover", dragOverCb);
        const dragEnterCb = (e) => {
            e.preventDefault();
            setDragOverTrack(true);
        };
        dropEl.addEventListener("dragenter", dragEnterCb);
        const dragLeaveCb = (e) => {
            e.preventDefault();
            setDragOverTrack(false);
        };
        dropEl.addEventListener("dragleave", dragLeaveCb);
        const dropCb = (e) => {
            e.preventDefault();
            setDragOverTrack(false);
            cb(e);
        };
        dropEl.addEventListener("drop", dropCb);
        return () => {
            dropEl.removeEventListener("dragover", dragOverCb);
            dropEl.removeEventListener("dragenter", dragEnterCb);
            dropEl.removeEventListener("dragleave", dragLeaveCb);
            dropEl.removeEventListener("drop", dropCb);
        };
    }, [dropEl]);
    return [setDropEl, dragOver];
};

==> hooks-1.0.9.tgz: package/lib/useFileDrop.js <==
import { debounce } from "@lincode/utils";
import { useEffect, useState } from "react";
export default (cb) => {
    const [el, setEl] = useState(null);
    const [dragOver, setDragOver] = useState(false);
    useEffect(() => {
        if (!el)
            return;
        const setDragOverDebounced = debounce((value) => setDragOver(value), 100, "trailing");
        let valueOld = false;
        const setDragOverTrack = (value) => {
            if (valueOld === value)
                return;
            valueOld = value;
            setDragOverDebounced(value);
        };
        const dragOverCb = (e) => {
            e.preventDefault();
            setDragOverTrack(true);
        };
        el.addEventListener("dragover", dragOverCb);
        const dragEnterCb = (e) => {
            e.preventDefault();
            setDragOverTrack(true);
        };
        el.addEventListener("dragenter", dragEnterCb);
        const dragLeaveCb = (e) => {
            e.preventDefault();
            setDragOverTrack(false);
        };
        el.addEventListener("dragleave", dragLeaveCb);
        const dropCb = (e) => {
            e.preventDefault();
            setDragOverTrack(false);
            cb(e);
        };
        el.addEventListener("drop", dropCb);
        return () => {
            el.removeEventListener("dragover", dragOverCb);
            el.removeEventListener("dragenter", dragEnterCb);
            el.removeEventListener("dragleave", dragLeaveCb);
            el.removeEventListener("drop", dropCb);
        };
    }, [el]);
    return [setEl, dragOver];
};
